#
# spec file for package maven-dependency-analyzer
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-dependency-analyzer
Version:        1.16.0
Release:        1.1
Summary:        Maven dependency analyzer
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/maven-dependency-analyzer/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/shared/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang3
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-lib
BuildRequires:  objectweb-asm
BuildRequires:  sisu-inject
BuildRequires:  slf4j
BuildRequires:  unzip
BuildArch:      noarch

%description
Analyzes the dependencies of a project for undeclared or unused artifacts.

Warning: Analysis is not done at source but bytecode level, then some cases are
not detected (constants, annotations with source-only retention, links in
javadoc) which can lead to wrong result if they are the only use of a
dependency.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
%{summary}

%prep
%setup -q
cp %{SOURCE1} build.xml

%build
mkdir -p lib
build-jar-repository -s lib \
    apache-commons-lang3 \
    atinject \
    commons-io \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    objectweb-asm/asm \
    org.eclipse.sisu.inject \
    slf4j/api

%{ant} \
    -Dtest.skip=true \
    jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Sat Apr 19 2025 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.16.0
  * New features and improvements
    + Enable GitHub Issues
  * Bug Fixes
    + MSHARED-47: Don't flag xml-apis:xml-apis as undeclared
  * Maintenance
    + Remove unneeded suppression
  * Dependency updates
    + Bump org.apache.maven.shared:maven-shared-components from 43
    to 44
    + Bump org.ow2.asm:asm from 9.7.1 to 9.8
    + Bump org.assertj:assertj-bom from 3.27.2 to 3.27.3
    + Bump org.assertj:assertj-bom from 3.26.3 to 3.27.2
* Tue Oct 29 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.15.1
  * Dependency upgrade
    + MSHARED-1432: Bump org.ow2.asm:asm from 9.7 to 9.7.1
* Tue Oct 15 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.15.0
  * Changes:
    + MSHARED-1248: update commons-io to 2.13.0
    + MSHARED-1248: maven-dependency-analyzer should log instead of
    failing
    + remove unused variable
    + MSHARED-1347: Include invoke dynamic bootstrap types in
    analysis
    + MSHARED-1356: Upgrade Parent to 41
    + Use new property for maven-plugin-tools version
    + MSHARED-1372: Bump org.ow2.asm:asm from 9.6 to 9.7
    + MSHARED-1272: Bump commons-io:commons-io from 2.16.0 to 2.16.1
    + MSHARED-1356: Bump
    org.apache.maven.shared:maven-shared-components from 41 to 42
    + MSHARED-1395: Remove dependency on commons-io
    + MSHARED-1393: Allow to exclude classes from verification
    + MSHARED-1394: Upgrade Maven core dependencies to the latest
    and mark as provided
    + MSHARED-1398: Fix StringIndexOutOfBoundsException in dynamic
    bootstrap types
    + MSHARED-1407: Track dependency usage by referencing classes
    + MSHARED-1410: Track used declared dependency usage by
    referencing classes
    + MSHARED-1428: Bump
    org.apache.maven.shared:maven-shared-components from 42 to 43
    + MSHARED-1429: Bump mavenVersion from 3.9.6 to 3.9.9
* Wed Sep 27 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.13.2
  * Changes
    + MSHARED-761: Make mvn dependency:analyze work with OpenJDK 11
    + MSHARED-786: jdk8 incompatibility at runtime
    (NoSuchMethodError)
    + MSHARED-870: Upgrade asm to 8.0.1
    + use try with resources to avoid leaks
    + MDEP-708: dependency:analyze recommends test scope for
    test-only artifacts that have non-test scope
    + remove reference to deprecated public mutable field
    + MDEP-712: update JIRA URL
    + MDEP-708: dependency:analyze should recommend narrower scope
    where possible
    + MSHARED-932: remove dependency on jmock
    + MDEP-753: inline deprecated field
    + MDEP-753: add more JavaDoc
    + MDEP-753: handle different classes from same artifact used by
    model and test code
    + MDEP-779: include class names in used undeclared dependencies
    + MSHARED-997: Check maximum allowed Maven version
    + MSHARED-1035: Get rid of maven-plugin-testing-tools for IT
    test
    + Require Maven 3.2.5+
    + MSHARED-1036: Analyze project classes only once
    + MSHARED-1039: Fix array parsing
    + MSHARED-1037: CONSTANT_METHOD_TYPE should not add to classes
    + MSHARED-1038: Inner classes are in same compilation unit as
    container class
    + MSHARED-1085: Upgrade Parent to 36
    + MSHARED-1119: Cleanup IT tests
    + MSHARED-894: replace Codehaus Plexus utils with
    java.nio.file.Files and Apache Commons
    + MDEP-757: bug with "non-test scoped test only dependencies
    found"
    + MSHARED-1218: Bump asm from 9.4 to 9.5
    + MSHARED-1220: Refresh download page
    + MSHARED-1219: Upgrade Parent to 39
    + MSHARED-1205: Build on JDK 19, 20
    + MSHARED-1224: Prefer JDK classes to Plexus utils
    + MSHARED-1149: Replace System.out by logger
    + MSHARED-1247: java.lang.RuntimeException: Unknown constant
    pool type
    + MSHARED-1249: Switch to JUnit 5
    + MSHARED-1250: Dependency improvements
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Remove unnecessary dependency on xmvn tools and parent pom
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not build against the legacy guava20 any more
* Tue Mar 26 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-dependency-analyzer 1.10
- Generate and customize ant build.xml file
